@@ -1,12 +1,14 @@
+use std::collections::BTreeMap;
 use std::ffi::OsStr;
 use std::io::Write;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 
 use ansi_term::Colour::Yellow;
 use anyhow::{Context, Result};
+use indexmap::IndexSet;
 
 use crate::helper::alphabet;
-use crate::helper::stats::{CharSummary, Chars, Completeness, SiteSummary, Sites};
+use crate::helper::stats::{CharSummary, Chars, Completeness, SiteSummary, Sites, Taxa};
 use crate::helper::types::DataType;
 use crate::helper::utils;
 use crate::writer::FileWriter;
@@ -26,30 +28,91 @@ impl FileWriter for CsvWriter<'_> {}
 
 pub struct CsvWriter<'a> {
     output: &'a Path,
+    prefix: &'a Option<String>,
     datatype: &'a DataType,
+    stats: &'a [(Sites, Chars, Taxa)],
 }
 
 impl<'a> CsvWriter<'a> {
-    pub fn new(output: &'a Path, datatype: &'a DataType) -> Self {
-        Self { output, datatype }
+    pub fn new(
+        output: &'a Path,
+        prefix: &'a Option<String>,
+        datatype: &'a DataType,
+        stats: &'a [(Sites, Chars, Taxa)],
+    ) -> Self {
+        Self {
+            output,
+            prefix,
+            datatype,
+            stats,
+        }
     }
 
-    pub fn write_summary_dir(&mut self, stats: &[(Sites, Chars)]) -> Result<()> {
-        let mut writer = self.create_output_file(self.output)?;
+    pub fn write_taxon_summary(&self, ids: &IndexSet<String>) -> Result<()> {
+        let default_prefix = "taxon_summary";
+        let output = match self.prefix {
+            Some(fname) => {
+                let out_name = format!("{}_{}", fname, default_prefix);
+                self.create_output_fnames(&out_name)
+            }
+            None => self.create_output_fnames(default_prefix),
+        };
+        let mut writer = self.create_output_file(&output)?;
+        writeln!(writer, "taxon,locus_counts,site_counts")?;
+        let taxon_summary = self.get_taxon_summary(ids);
+        taxon_summary.iter().for_each(|(taxa, counts)| {
+            let loci_counts = counts.len();
+            let site_counts = counts.iter().sum::<usize>();
+            writeln!(writer, "{},{},{}", taxa, loci_counts, site_counts)
+                .expect("Failed taxon summary stats");
+        });
+        Ok(())
+    }
+
+    pub fn write_locus_summary(&self) -> Result<()> {
+        let default_prefix = "locus_summary";
+        let output = match self.prefix {
+            Some(fname) => {
+                let out_name = format!("{}_{}", fname, default_prefix);
+                self.create_output_fnames(&out_name)
+            }
+            None => self.create_output_fnames(default_prefix),
+        };
+        let mut writer = self.create_output_file(&output)?;
         let alphabet = self.get_alphabet(self.datatype);
-        self.write_csv_header(&mut writer, alphabet)?;
-        stats.iter().for_each(|(site, chars)| {
-            self.write_csv_content(&mut writer, site, chars, alphabet)
+        self.write_locus_header(&mut writer, alphabet)?;
+        self.stats.iter().for_each(|(site, chars, _)| {
+            self.write_locus_content(&mut writer, site, chars, alphabet)
                 .unwrap();
         });
 
-        log::info!("{}", Yellow.paint("Output Files"));
-        log::info!("{:18}: {}", "Alignment summary", self.output.display());
+        log::info!("{}", Yellow.paint("Output"));
+        log::info!("{:18}: {}", "Output dir", self.output.display());
 
         Ok(())
     }
 
-    fn write_csv_header<W: Write>(&self, writer: &mut W, alphabet: &str) -> Result<()> {
+    fn create_output_fnames(&self, prefix: &str) -> PathBuf {
+        self.output.join(prefix).with_extension("csv")
+    }
+
+    fn get_taxon_summary(&self, ids: &IndexSet<String>) -> BTreeMap<String, Vec<usize>> {
+        let mut taxon_summary = BTreeMap::new();
+        self.stats.iter().for_each(|(_, _, taxa)| {
+            ids.iter().for_each(|id| match taxa.records.get(id) {
+                Some(site_counts) => {
+                    taxon_summary
+                        .entry(id.to_string())
+                        .or_insert(vec![])
+                        .push(site_counts.clone());
+                }
+                None => (),
+            })
+        });
+        taxon_summary
+    }
+
+    fn write_locus_header<W: Write>(&self, writer: &mut W, alphabet: &str) -> Result<()> {
         write!(
             writer,
             "path,\
@@ -76,7 +139,7 @@ impl<'a> CsvWriter<'a> {
         Ok(())
     }
 
-    fn write_csv_content<W: Write>(
+    fn write_locus_content<W: Write>(
         &self,
         writer: &mut W,
         site: &Sites,
